# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog,
and this project adheres to Semantic Versioning.

## [1.1.1] - 2026-03-22



### Maintenance

- Migrate to opencode workflow


## [1.1.0] - 2026-03-13



### Added

- **cli:** Add global config and multi-inbox support


### Fixed

- Prevent nox from mutating lockfile


### Maintenance

- Release v1.1.0


## [1.0.1] - 2026-03-13



### Fixed

- **version:** Read installed package version


### Maintenance

- Release v1.0.1


## [1.0.0] - 2026-03-12



### Added

- **cli:** Implement AI-powered file renaming workflow 


### Maintenance

- Release v1.0.0


## [0.1.0] - 2026-03-12



### Maintenance

- Initial project setup

- **repo:** Complete OSS setup for renamr

- Release v0.1.0

<!-- generated by git-cliff -->
